@@ -76,9 +76,15 @@ def test_plugin_runner(socketio_server):
             f"--server-url=http://127.0.0.1:{PORT}",
             "--quit-on-ready",
             os.path.join(os.path.dirname(__file__), "example_plugin.py"),
-        ]
-    ):
-        pass
+        ],
+        stdout=subprocess.PIPE,
+        stderr=subprocess.PIPE,
+    ) as proc:
+        out, err = proc.communicate()
+        assert err.decode("utf8") == ""
+        output = out.decode("utf8")
+        assert "Generated token: imjoy@" in output
+        assert "echo: a message" in output
 
 
 async def test_workspace(socketio_server):
@@ -137,6 +143,11 @@ async def test_workspace(socketio_server):
     plugin = await api2.get_plugin("my plugin 2")
     assert plugin.foo == "bar"
 
+    await api2.export({"foo2": "bar2"})
+    plugin = await api2.get_plugin("my plugin 2")
+    assert plugin.foo is None
+    assert plugin.foo2 == "bar2"
+
     with pytest.raises(Exception, match=r".*Plugin my plugin 2 not found.*"):
         await api.get_plugin("my plugin 2")
 
